#!/usr/bin/python
# -*- coding: UTF-8 -*-
"""
@author:lei
@file:core.py
@time:2022/05/22
@邮箱：leigang431@163.com
"""

def lg():
    print("雷钢:一个乐观积极向上的人!")

def ywj():
    print("殷文俊:一个乐观积极向上的人!")

def lsc():
    print("李升晨:一个乐观积极向上的人!")

def pb():
    print("彭博:一个乐观积极向上的人!")

def cxy():
    print("陈星宇:一个乐观积极向上的人!")

def all():
    print("祝南5舍629的兄弟们前程似锦!")